Mitts

- TorchedHops - great beer ML name
- Mitts
- Torch oopsie
- Fire safety
- Smoke alarm

Goal: Prevent “oopsies” with PyTorch

Examples
- All of an input or output are the same (or missing)
- Gradients aren’t updating
- Inputs aren’t normalized
- Vanishing/Exploding gradient?
- Training/Test Overlap



To Deploy
python3 -m build
python3 -m twine upload dist/*